@@ -1,7 +1,7 @@
 package Dancer::Session::Abstract;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: abstract class for session engine
-$Dancer::Session::Abstract::VERSION = '1.3300'; # TRIAL
+$Dancer::Session::Abstract::VERSION = '1.3301'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -104,7 +104,7 @@ sub read_session_id {
 
     my $name = $class->session_name();
     my $c    = Dancer::Cookies->cookies->{$name};
-    return (defined $c && $c->value =~ /^\d+$/) ? $c->value : undef;
+    return (defined $c) ? $c->value : undef;
 }
 
 sub write_session_id {
@@ -144,7 +144,7 @@ Dancer::Session::Abstract - abstract class for session engine
 
 =head1 VERSION
 
-version 1.3300
+version 1.3301
 
 =head1 DESCRIPTION
 
